==> afya_moja_core-0.0.1.tar.gz: README.md <==
[![Release](https://img.shields.io/badge/PreRelease-^0.0.1-red.svg?style=for-the-badge)](https://shields.io/)
[![Maintained](https://img.shields.io/badge/Maintained-Actively-informational.svg?style=for-the-badge)](https://shields.io/)

# afya_moja_core

`afya_moja_core` is an open source project &mdash; it's one among many other shared libraries that make up the wider ecosystem of software made and open sourced by `Savannah Informatics Limited`.

A shared library for `afyamoja` and `myafyahub` that is responsible for rendering and exposing shared components

## Installation Instructions

Use this package as a library by depending on it

Run this command:

- With Flutter:

```dart
$ flutter pub add afya_moja_core
```

This will add a line like this to your package's pubspec.yaml (and run an implicit dart pub get):

```dar
dependencies:
  afya_moja_core: ^0.0.1
```

Alternatively, your editor might support flutter pub get. Check the docs for your editor to learn more.

Lastly:

Import it like so:

```dart
import 'package:afya_moja_core/buttons.dart';
```

## Usage

Check the [example](https://github.com/savannahghi/misc_utilities/blob/main/example/main.dart) provided for how to use this package.

## Dart & Flutter Version

- Dart 2: >= 2.12
- Flutter: >=2.0.0

## Developing & Contributing

First off, thanks for taking the time to contribute!

Be sure to check out detailed instructions on how to contribute to this project [here](https://github.com/savannahghi/afya_moja_core/blob/main/CONTRIBUTING.md) and go through out [Code of Conduct](https://github.com/savannahghi/afya_moja_core/blob/main/CODE_OF_CONDUCT.md).

GPG Signing:
As a contributor, you need to sign your commits. For more details check [here](https://docs.github.com/en/github/authenticating-to-github/managing-commit-signature-verification/signing-commits)

## License

This library is distributed under the MIT license found in the [LICENSE](https://github.com/savannahghi/afya_moja_core/blob/main/LICENSE) file.

==> afya_moja_core-0.0.3.tar.gz: README.md <==
[![Release](https://img.shields.io/badge/Version-^0.0.37-success.svg?style=for-the-badge)](https://shields.io/)
[![Maintained](https://img.shields.io/badge/Maintained-Actively-informational.svg?style=for-the-badge)](https://shields.io/)
[![Release](https://img.shields.io/badge/Coverage-100-success.svg?style=for-the-badge)](https://shields.io/)

# afya_moja_core

`afya_moja_core` is an open source project &mdash; it's one among many other shared libraries that make up the wider ecosystem of software made and open sourced by `Savannah Informatics Limited`.

A shared library for `afyamoja` and `myafyahub` that is responsible for rendering and exposing shared components

## Installation Instructions

Use this package as a library by depending on it

Run this command:

- With Flutter:

```dart
flutter pub add afya_moja_core
```

This will add a line like this to your package's pubspec.yaml (and run an implicit dart pub get):

```dart
dependencies:
  afya_moja_core: ^0.0.37
```

Alternatively, your editor might support flutter pub get. Check the docs for your editor to learn more.

Lastly:

Import it like so:

```dart
import 'package:afya_moja_core/buttons.dart';
```

## Usage

Check the [example](https://github.com/savannahghi/misc_utilities/blob/main/example/main.dart) provided for how to use this package.

## Dart & Flutter Version

- Dart 2: >= 2.12
- Flutter: >=2.0.0

## Developing & Contributing

First off, thanks for taking the time to contribute!

Be sure to check out detailed instructions on how to contribute to this project [here](https://github.com/savannahghi/afya_moja_core/blob/main/CONTRIBUTING.md) and go through out [Code of Conduct](https://github.com/savannahghi/afya_moja_core/blob/main/CODE_OF_CONDUCT.md).

GPG Signing:
As a contributor, you need to sign your commits. For more details check [here](https://docs.github.com/en/github/authenticating-to-github/managing-commit-signature-verification/signing-commits)

## License

This library is distributed under the MIT license found in the [LICENSE](https://github.com/savannahghi/afya_moja_core/blob/main/LICENSE) file.
